pub enum Access {
Both,
Workers,
Cli,
}Expand description
Which client(s) this Orchestrator service accepts.
Default: a single service that accepts both Workers and the CLI.
With --cli_port create a separate Orchestrator service for Workers and CLI.
Variants
Implementations
Sourceimpl Access
impl Access
Sourcefn serves_workers(self) -> bool
fn serves_workers(self) -> bool
Accept Worker calls (worker_connect, send_result, measurement_finished)
Sourcefn serves_cli(self) -> bool
fn serves_cli(self) -> bool
Accept CLI calls (do_measurement, live_measurement, list_workers)