pub struct TracerouteConfig {
pub session_tracker: SessionTracker,
pub origin_id: u32,
pub timeout: u64,
pub max_hops: u32,
pub initial_hop: u32,
pub max_failures: u32,
pub star_unresponsive: bool,
}Expand description
Traceroute configuration
Fields
session_tracker: SessionTrackerSession tracker for Trace Tasks
origin_id: u32Origin tracemap seed probes are sent from (anycast-traceroute sessions instead use the origin that caught the discovery reply)
timeout: u64Timeout value for traceroute measurements (default 3s)
max_hops: u32Max hop count for traceroute measurements (default 25)
initial_hop: u32Hop count to start traceroute measurements with (default 4)
max_failures: u32Maximum number of unresponsive hops before terminating the traceroute (default 5; tracemap confirmation window: 3)
star_unresponsive: boolWhether to emit a ‘*’ hop (no reply) to the CLI when a hop times out